@@ -32,3 +32,6 @@ class Component(Base):
                 .handle_operation()\
                 .get_output_streams()
     return streams
+
+  def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", prepare=None, begin_cycle=None, next_tuple=None):
+    return Base._source_common(self, ComponentStream, name, matches, options, emits, end_cycle_policy, prepare, begin_cycle, next_tuple)
